Stan Math Library: stan::math::apply_scalar_unary< F, stan::math::fvar< T > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Static Public Member Functions | List of all members
stan::math::apply_scalar_unary< F, stan::math::fvar< T > > Struct Template Reference

Template specialization to fvar for vectorizing a unary scalar function. More...

`#include <apply_scalar_unary.hpp>`

## Public Types
typedef stan::math::fvar< T > | return_t
| Function return type, which is same as the argument type for the function, `fvar<T>`. More...

## Static Public Member Functions
static return_t | apply (const stan::math::fvar< T > &x)
| Apply the function specified by F to the specified argument. More...

## Detailed Description

### template<typename F, typename T>
struct stan::math::apply_scalar_unary< F, stan::math::fvar< T > >

Template specialization to fvar for vectorizing a unary scalar function.

This is a base scalar specialization. It applies the function specified by the template parameter to the argument.

Template Parameters

  F | Type of function to apply.
  T | Value and tangent type for for forward-mode autodiff variable.

Definition at line 22 of file apply_scalar_unary.hpp.

## Member Typedef Documentation

template<typename F , typename T >

typedef stan::math::fvar<T> stan::math::apply_scalar_unary< F, stan::math::fvar< T > >::return_t

Function return type, which is same as the argument type for the function, `fvar<T>`.

Definition at line 27 of file apply_scalar_unary.hpp.

## Member Function Documentation

template<typename F , typename T >

static return_t stan::math::apply_scalar_unary< F, stan::math::fvar< T > >::apply | ( | const stan::math::fvar< T > & | x | ) |
| inlinestatic

Apply the function specified by F to the specified argument.

Parameters

  x | Argument variable.

Returns
  Function applied to the variable.

Definition at line 35 of file apply_scalar_unary.hpp.

The documentation for this struct was generated from the following file:

- stan/math/fwd/mat/vectorize/apply_scalar_unary.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.